Document

Struct Document 

pub struct Document {
    pub content: Rope,
    pub tree: Option<Tree>,
    pub uri: Url,
    pub version: i32,
}

Fields

content: Ropetree: Option<Tree>uri: Urlversion: i32

Implementations

Source

impl Document

pub fn aliases(&self) -> Vec<Alias>

pub fn apply_change( &mut self, params: DidChangeTextDocumentParams, ) -> Result<(), Error>

Applies incremental edits from the client and reparses the syntax tree.

Errors

Returns an Error if tree-sitter fails to parse the updated document.

pub fn attributes(&self) -> Vec<Attribute>

pub fn find_function(&self, name: &str) -> Option<Function>

pub fn find_recipe(&self, name: &str) -> Option<Recipe>

pub fn find_variable(&self, name: &str) -> Option<Variable>

pub fn format(&self) -> Result<String, Error>

Errors

Returns an Error if formatting fails.

pub fn function_calls(&self) -> Vec<FunctionCall>

pub fn functions(&self) -> Vec<Function>

pub fn get_node_text(&self, node: &Node<'_>) -> String

pub fn imports(&self) -> Vec<Import>

pub fn modules(&self) -> Vec<Module>

pub fn new(source: &str, uri: Url) -> Result<Self, Error>

Errors

Returns an Error if the tree-sitter parser cannot be created or the contents fail to parse.

pub fn node_at_position(&self, position: Position) -> Option<Node<'_>>

Returns the syntax tree node at the given LSP Position.

pub fn parse(&mut self) -> Result<(), Error>

Parses the current document contents and updates the cached syntax tree.

Errors

Returns an Error if the tree-sitter parser cannot be created or the contents fail to parse.

pub fn recipes(&self) -> Vec<Recipe>

pub fn settings(&self) -> Vec<Setting>

pub fn variables(&self) -> Vec<Variable>